(ns org.aplex.rest-sendgrid.core
  (:require
   [ajax.core :refer [json-request-format json-response-format]]
   [org.aplex.helpers.interface :as h]))

(def version "v3")
(def api-config (atom {:api-host "https://api.sendgrid.com/"
                       :api-key (h/get-env "SENDGRID_API_KEY" "NO API KEY SUPPLIED")}))

(defn default-authed-payload []
  {:headers {"Authorization" (str "Bearer " (:api-key @api-config))
             "content-type" "application/json"}})

(defn init-config [cfg]
  (reset! api-config (merge @api-config cfg)))

(defn build-url [path]
  (str (:api-host @api-config) version path))

(defn send-email
  "https://docs.sendgrid.com/api-reference/mail-send/mail-send"
  [email]
  (merge (default-authed-payload)
         {:uri (build-url "/mail/send")
          :method :post
          :format (json-request-format)
          :response-format (json-response-format {:keywords? true})
          :keywords? true
          :params email}))

(comment (send-email {:to ""}))
